import { DynamoDBClient, GetItemCommand, QueryCommand } from '@aws-sdk/client-dynamodb';
import { unmarshall } from '@aws-sdk/util-dynamodb';
import { mapGetItemCommand } from './mapper/mapGetItemCommand';
import { mapGetItemsCommand } from './mapper/mapGetItemsCommand';
import { mapGetItemIndexCommand } from './mapper/mapGetItemIndexCommand';
import { formatKey } from './formatter/formatKey';
export class DDBReadOnlyClient {
    config;
    client;
    constructor(config) {
        this.config = config;
        this.client = new DynamoDBClient(config.configuration || {});
    }
    async getItem(partitionKey, sortKey) {
        try {
            this.requireFullPrimaryKey(partitionKey, sortKey);
            if (!this.config.indexName) {
                const response = await this.client.send(new GetItemCommand(mapGetItemCommand(this.config, partitionKey, sortKey)));
                return response?.Item ? unmarshall(response?.Item) : null;
            }
            else {
                const response = await this.client.send(new QueryCommand(mapGetItemIndexCommand(this.config, partitionKey, sortKey)));
                const items = this.extractItems(response);
                return items.length > 0 ? items[0] : null;
            }
        }
        catch (err) {
            console.error(formatKey(this.config, partitionKey, sortKey));
            throw new Error(err);
        }
    }
    async getItems(partitionKey, sortKeyPrefix) {
        try {
            const response = await this.client.send(new QueryCommand(mapGetItemsCommand(this.config, partitionKey, sortKeyPrefix)));
            return this.extractItems(response);
        }
        catch (err) {
            console.error(formatKey(this.config, partitionKey, sortKeyPrefix));
            throw new Error(err);
        }
    }
    extractItems(response) {
        return response?.Items?.map(item => unmarshall(item)) || [];
    }
    requireFullPrimaryKey(partitionKey, sortKey) {
        if (!partitionKey)
            throw new Error(`Missing partitionKey.`);
        if (this.config.sortKeyName && !sortKey)
            throw new Error(`Missing sortKey.`);
    }
}
